#
# spec file for package kdeconnect-kde
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define kf6_version 6.6.0
%define qt6_version 6.6.0

%bcond_without released
Name:           kdeconnect-kde
Version:        25.04.0
Release:        1.1
Summary:        Integration of Android with Linux desktops
License:        GPL-2.0-or-later
URL:            https://apps.kde.org/kdeconnect
Source0:        https://download.kde.org/stable/release-service/%{version}/src/%{name}-%{version}.tar.xz
%if %{with released}
Source1:        https://download.kde.org/stable/release-service/%{version}/src/%{name}-%{version}.tar.xz.sig
Source2:        applications.keyring
%endif
Source100:      kdeconnect-kde.SuSEfirewall
# PATCH-FIX-UPSTREAM
Patch0:         0001-Fix-build-on-32bit-archs.patch
BuildRequires:  kf6-extra-cmake-modules >= %{kf6_version}
BuildRequires:  pkgconfig
BuildRequires:  qt6-gui-private-devel >= %{qt6_version}
BuildRequires:  cmake(KF6ConfigWidgets) >= %{kf6_version}
BuildRequires:  cmake(KF6Crash) >= %{kf6_version}
BuildRequires:  cmake(KF6DBusAddons) >= %{kf6_version}
BuildRequires:  cmake(KF6DocTools) >= %{kf6_version}
BuildRequires:  cmake(KF6GuiAddons) >= %{kf6_version}
BuildRequires:  cmake(KF6I18n) >= %{kf6_version}
BuildRequires:  cmake(KF6IconThemes) >= %{kf6_version}
BuildRequires:  cmake(KF6KCMUtils) >= %{kf6_version}
BuildRequires:  cmake(KF6KIO) >= %{kf6_version}
BuildRequires:  cmake(KF6Kirigami2) >= %{kf6_version}
BuildRequires:  cmake(KF6KirigamiAddons) >= 0.11
BuildRequires:  cmake(KF6ModemManagerQt) >= %{kf6_version}
BuildRequires:  cmake(KF6Notifications) >= %{kf6_version}
BuildRequires:  cmake(KF6Package) >= %{kf6_version}
BuildRequires:  cmake(KF6People) >= %{kf6_version}
BuildRequires:  cmake(KF6PulseAudioQt)
BuildRequires:  cmake(KF6QQC2DesktopStyle) >= %{kf6_version}
BuildRequires:  cmake(KF6Service) >= %{kf6_version}
BuildRequires:  cmake(KF6Solid) >= %{kf6_version}
BuildRequires:  cmake(KF6StatusNotifierItem) >= %{kf6_version}
BuildRequires:  cmake(KF6WindowSystem) >= %{kf6_version}
BuildRequires:  cmake(Qt6Bluetooth) >= %{qt6_version}
BuildRequires:  cmake(Qt6DBus) >= %{qt6_version}
BuildRequires:  cmake(Qt6Multimedia) >= %{qt6_version}
BuildRequires:  cmake(Qt6Network) >= %{qt6_version}
BuildRequires:  cmake(Qt6Quick) >= %{qt6_version}
BuildRequires:  cmake(Qt6QuickControls2) >= %{qt6_version}
BuildRequires:  cmake(Qt6QuickWidgets) >= %{qt6_version}
BuildRequires:  cmake(Qt6WaylandClient) >= %{qt6_version}
BuildRequires:  pkgconfig(dbus-1)
BuildRequires:  pkgconfig(libfakekey)
BuildRequires:  pkgconfig(openssl)
BuildRequires:  pkgconfig(wayland-protocols)
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xkbcommon)
BuildRequires:  pkgconfig(xtst)
Requires:       kf6-kirigami-imports >= %{kf6_version}
Requires:       kf6-kpeople-imports >= %{kf6_version}
Requires:       kf6-qqc2-desktop-style >= %{kf6_version}
Requires:       kirigami-addons6
Requires:       qt6-declarative-imports >= %{qt6_version}
Requires:       qt6-multimedia-imports >= %{qt6_version}
Requires:       sshfs >= 3.7.2
Conflicts:      kdeconnect-kde4

%description
A package for integration of Android with Linux desktops.

Current feature list:
- Clipboard share: copy from or to your desktop
- Notifications sync (4.3+): Read your Android notifications
- Multimedia remote control: Use your phone as a remote control
- WiFi connection: no USB wire or Bluetooth needed
- RSA Encryption: your information is safe

Please note you will need to install KDE Connect on Android for this app to work:
https://play.google.com/store/apps/details?id=org.kde.kdeconnect_tp or
https://f-droid.org/en/packages/org.kde.kdeconnect_tp/

%package zsh-completion
Summary:        ZSH completion for kdeconnect-kde
Requires:       kdeconnect-kde = %{version}
Supplements:    (kdeconnect-kde and zsh)
BuildArch:      noarch

%description zsh-completion
ZSH command line completion support for kdeconnect-kde.

%lang_package

%prep
%autosetup -p1

%build
%cmake_kf6 -DBUILD_WITH_QT6:BOOL=TRUE

%kf6_build

%install
%kf6_install

%find_lang %{name} --with-html --all-name

# Remove unused static lib
rm %{buildroot}%{_kf6_libdir}/libkdeconnectinterfaces.a

%if 0%{?suse_version} < 1550
# susefirewall config file
install -D -m 0644 %{SOURCE100} \
    %{buildroot}%{_sysconfdir}/sysconfig/SuSEfirewall2.d/services/kdeconnect-kde
%endif

%pre
# migrate old kdeconnect-kde service
# XXX: can be removed after some time, the author would suggest after 2023-06-15 has passed
if grep -q kdeconnect-kde /etc/firewalld/zones/*.xml 2>/dev/null; then
    echo "Migrating 'kdeconnect-kde' firewalld service to identical 'kdeconnect' shipped with firewalld."
    sed -i 's/<service name="kdeconnect-kde"\/>/<service name="kdeconnect"\/>/' /etc/firewalld/zones/*.xml
    if firewall-cmd -q --state; then
        firewall-cmd --reload
    fi
fi
true
# migrate kdeconnect-kde end

%post
%ldconfig
%if 0%{?is_opensuse}
if [ $1 -eq 1 ]; then # inital/first package install
    if [ -x %{_bindir}/firewall-cmd ]; then
        echo 'Adding kdeconnect service to default and home firewalld zones'
        if firewall-cmd -q --state; then
            firewall-cmd -q --add-service=kdeconnect
            firewall-cmd -q --add-service=kdeconnect --zone=home
            firewall-cmd -q --runtime-to-permanent
        else
            firewall-offline-cmd -q --add-service=kdeconnect
            firewall-offline-cmd -q --add-service=kdeconnect --zone=home
        fi
    fi
fi
true
%endif

%postun
%ldconfig
%if 0%{?is_opensuse}
if [ $1 -eq 0 ]; then # last/final package removal
    if [ -x %{_bindir}/firewall-cmd ]; then
        echo 'Removing kdeconnect service from default and home firewalld zones'
        if firewall-cmd -q --state; then
            firewall-cmd -q --remove-service=kdeconnect
            firewall-cmd -q --remove-service=kdeconnect --zone=home
            firewall-cmd -q --runtime-to-permanent
        else
            firewall-offline-cmd -q --remove-service=kdeconnect
            firewall-offline-cmd -q --remove-service-from-zone=kdeconnect --zone=home
        fi
    fi
fi
true
%endif

%files zsh-completion
%dir %{_datadir}/zsh
%dir %{_datadir}/zsh/site-functions
%{_datadir}/zsh/site-functions/_kdeconnect

%files
%license LICENSES/*
%doc README*
%doc %lang(en) %{_kf6_htmldir}/en/kdeconnect*/
%if 0%{?suse_version} < 1550
%config(noreplace) %{_sysconfdir}/sysconfig/SuSEfirewall2.d/services/kdeconnect-kde
%endif
%{_kf6_applicationsdir}/kcm_kdeconnect.desktop
%{_kf6_applicationsdir}/org.kde.kdeconnect-settings.desktop
%{_kf6_applicationsdir}/org.kde.kdeconnect.app.desktop
%{_kf6_applicationsdir}/org.kde.kdeconnect.daemon.desktop
%{_kf6_applicationsdir}/org.kde.kdeconnect.handler.desktop
%{_kf6_applicationsdir}/org.kde.kdeconnect.nonplasma.desktop
%{_kf6_applicationsdir}/org.kde.kdeconnect.sms.desktop
%{_kf6_appstreamdir}/org.kde.kdeconnect.appdata.xml
%{_kf6_appstreamdir}/org.kde.kdeconnect.metainfo.xml
%{_kf6_bindir}/kdeconnect-app
%{_kf6_bindir}/kdeconnect-cli
%{_kf6_bindir}/kdeconnect-handler
%{_kf6_bindir}/kdeconnect-indicator
%{_kf6_bindir}/kdeconnect-settings
%{_kf6_bindir}/kdeconnect-sms
%{_kf6_bindir}/kdeconnectd
%{_kf6_configdir}/autostart/org.kde.kdeconnect.daemon.desktop
%{_kf6_debugdir}/kdeconnect-kde.categories
%{_kf6_iconsdir}/hicolor/*/apps/kdeconnect*.svg
%{_kf6_iconsdir}/hicolor/*/status/*.svg
%{_kf6_libdir}/libkdeconnectcore.so.*
%{_kf6_libdir}/libkdeconnectpluginkcm.so.*
%{_kf6_notificationsdir}/kdeconnect.notifyrc
%{_kf6_plasmadir}/plasmoids/org.kde.kdeconnect/
%{_kf6_plugindir}/kdeconnect/
%dir %{_kf6_plugindir}/kf6/kfileitemaction
%{_kf6_plugindir}/kf6/kfileitemaction/kdeconnectfileitemaction.so
%{_kf6_plugindir}/kf6/kio/kdeconnect.so
%{_kf6_plugindir}/plasma/kcms/systemsettings_qwidgets/kcm_kdeconnect.so
%{_kf6_qmldir}/org/kde/kdeconnect/
%dir %{_kf6_sharedir}/contractor
%{_kf6_sharedir}/contractor/kdeconnect.contract
%{_kf6_sharedir}/dbus-1/services/org.kde.kdeconnect.service
%dir %{_kf6_sharedir}/deepin
%dir %{_kf6_sharedir}/deepin/dde-file-manager
%dir %{_kf6_sharedir}/deepin/dde-file-manager/oem-menuextensions
%{_kf6_sharedir}/deepin/dde-file-manager/oem-menuextensions/kdeconnect-dde.desktop
%{_kf6_sharedir}/kdeconnect
%{_kf6_sharedir}/kdeconnect/kdeconnect_clipboard_config.qml
%{_kf6_sharedir}/kdeconnect/kdeconnect_findthisdevice_config.qml
%{_kf6_sharedir}/kdeconnect/kdeconnect_pausemusic_config.qml
%{_kf6_sharedir}/kdeconnect/kdeconnect_runcommand_config.qml
%{_kf6_sharedir}/kdeconnect/kdeconnect_sendnotifications_config.qml
%{_kf6_sharedir}/kdeconnect/kdeconnect_share_config.qml
%dir %{_kf6_sharedir}/nautilus-python
%dir %{_kf6_sharedir}/nautilus-python/extensions/
%{_kf6_sharedir}/nautilus-python/extensions/kdeconnect-share.py
%dir %{_kf6_sharedir}/Thunar
%dir %{_kf6_sharedir}/Thunar/sendto
%{_kf6_sharedir}/Thunar/sendto/kdeconnect-thunar.desktop

%files lang -f %{name}.lang
%exclude %{_kf6_htmldir}/en/kdeconnect*/

%changelog
* Mon Apr 14 2025 Christophe Marin <christophe@krop.fr>
- Update to 25.04.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/25.04.0/
- Changes since 25.03.90:
  * app/DevicePage: use DelegateModel to filter list
  * Generate IDs with only alphanumeric values
- Add patch:
  * 0001-Fix-build-on-32bit-archs.patch
* Tue Apr  8 2025 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 25.03.90
  * New feature release
- Too many changes since 24.12.3, only listing bugfixes:
  * app: make sidebar keyboard-accessible (kde#484709)
  * smsapp: remember window state (kde#499651)
- Drop patches, now upstream:
  * 0001-Add-missing-include.patch
* Tue Apr  8 2025 Fabian Vogt <fabian@ritter-vogt.de>
- Add patch to fix build against Qt 6.9:
  * 0001-Add-missing-include.patch
* Tue Mar  4 2025 Christophe Marin <christophe@krop.fr>
- Update to 24.12.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.12.3/
- No code change since 24.12.2
* Tue Feb  4 2025 Christophe Marin <christophe@krop.fr>
- Update to 24.12.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.12.2/
- No code change since 24.12.1
* Tue Jan  7 2025 Christophe Marin <christophe@krop.fr>
- Update to 24.12.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.12.1/
- Changes since 24.12.0:
  * plugins/findthisdevice: fix broken qml config page
  * [kio] Don't query mountpoint twice
  * [kio] Handle error when getting mount point
  * Add icons to the app plugin config list
* Sun Dec  8 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.12.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/24.12.0/
- No code change since 24.11.90
* Mon Dec  2 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.11.90
  * New feature release
- No code change since 24.11.80
* Sat Nov 16 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.11.80
  * New feature release
- Too many changes since 24.08.3, only listing bugfixes:
  * kcm: improve description field in json (kde#466256)
  * plugins/runcommand: use Kirigami.Dialog (kde#487438)
  * Bluetooth provider workaround for BlueZ/DBus timeouts (kde#481870)
* Tue Nov  5 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.08.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.08.3/
- No code change since 24.08.2
* Tue Oct  8 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.08.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.08.2/
- Changes since 24.08.1:
  * Don't set an absolute D-Bus service path on Windows and macOS
  * Revert "Revert "Use absolute path in D-Bus service file""
* Tue Sep 10 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.08.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.08.1/
- Changes since 24.08.0:
  * Revert changes to QML incompatible with Qt 6.6 and older
* Mon Aug 19 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.08.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/24.08.0/
- Too many changes since 24.05.2, only listing bugfixes:
  * Bluetooth provider workaround for BlueZ/DBus timeouts (kde#481870)
  * Corrected newline inserting when using shift+return while writing SMS messages (kde#488585)
  * virtualmonitor: implemented capabilities check (kde#485829)
  * Fixed virtualmonitorplugin url generation (kde#485830)
* Tue Jul  2 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.05.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.05.2/
- No code change since 24.05.1
* Wed Jun 12 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.05.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.05.1/
- Changes since 24.05.0:
  * Make clang-format happy
  * Add Qt::DBus dependency to kdeconnect_runcommand_config
* Sun May 19 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.05.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/24.05.0/
- Changes since 24.04.80:
  * Remove no longer necessary Qt6Core5Compat dependency
* Fri May  3 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.04.80
  * New feature release
- Changes since 24.02.2:
  * [filetransferjob] Simplify error handling
  * Add 24.02.0 Windows artifact
  * smsapp/conversation list: Fix formatting issues and refactor code
  * fix: do not send NetworkPacket if autoshare is disabled when connecting (kde#476551)
  * Fix incorrect filename for duplicate copies on notification displays The filename is just changed after notification is displayed. (kde#484727)
  * Make clang-format happy
  * smsapp/qml: Remove explicit column height binding
  * smsapp: Clean up conversation list title elements
  * smsapp/attachments: Remove Qt5Compat import
  * smsapp: Use Kirigami.ShadowedRectangle instead of DropShadow
  * smsapp/qml: Remove unneeded imports
  * Improve accessibility based on HAN university accessibility report
  * smsapp/qml: Define explicit params in signal handlers
  * Remove QTextCodec usage
  * Apply 2 suggestion(s) to 2 file(s)
  * Don't install kdeconnectd in libexec
  * [kcm] Use correct KCModule constructor (kde#482199)
  * sftp: --warning
  * app: Put the Placeholder inside the view
  * Remove unused dependency
  * Remove `master` dependency overrides from craft config
  * Disable Bluetooth backend due to kde#482192
  * singlerelease is actually used
  * [plugins/mousepad]: Add support for the persistence feature of the RemoteDesktop portal (kde#479013)
  * [plugins/telephony] Clear actions before creating new notification action (kde#479904)
  * Use StartupNotify now instead of X-KDE-StartupNotify
* Tue Apr  9 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.02.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.02.2/
- Changes since 24.02.1:
  * Make clang-format happy
* Tue Mar 19 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.02.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.02.1/
- Changes since 24.02.0:
  * app: Put the Placeholder inside the view
  * [kcm] Use correct KCModule constructor (kde#482199)
  * Remove `master` dependency overrides from craft config
  * Disable Bluetooth backend due to https://bugs.kde.org/482192
- Drop patch, merged upstream:
  * 0001-Disable-Bluetooth-backend-due-to-https-bugs.kde.org-.patch
* Sat Mar 16 2024 Christophe Marin <christophe@krop.fr>
- Add missing runtime requirements (boo#1221440)
* Wed Mar 13 2024 Christophe Marin <christophe@krop.fr>
- Add upstream change to work around kde#482192:
  * 0001-Disable-Bluetooth-backend-due-to-https-bugs.kde.org-.patch
* Fri Feb 23 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.02.0
  * New feature release
- No code change since 24.01.95
* Fri Feb  9 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.01.95
  * https://kde.org/announcements/megarelease/6/rc2/
* Tue Dec  5 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.08.4
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.08.4/
- No code change since 23.08.3
* Tue Nov  7 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.08.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.08.3/
- No code change since 23.08.2
* Tue Oct 10 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.08.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.08.2/
- Changes since 23.08.1:
  * Iterate KFilePlacesModel instead of using closestItem to remove SFTP entries (kde#461872)
  * Remove "Open on connected device via KDE Connect" (kde#472697)
* Tue Sep 12 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.08.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.08.1/
- Changes since 23.08.0:
  * Sanitize certificate subject name before comparing to deviceId
  * Fix remote keyboard sending "space" when pressing space (kde#473956)
  * Fix SFTP plugin on Windows (kde#473511)
* Wed Aug 30 2023 Fabian Vogt <fabian@ritter-vogt.de>
- Remove the kdeconnect_open handler to work around kde#472697
* Sun Aug 20 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.08.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/23.08.0/
- Changes since 23.07.90:
  * Remove QIcon loading to avoid pre-stage D-Bus session cache
  * Fix potential race condition
* Mon Aug 14 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.07.90
  * New feature release
- Changes since 23.07.80:
  * Set `GVFS_REMOTE_VOLUME_MONITOR_IGNORE` to avoid potential crashes
* Tue Aug  1 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.07.80
  * New feature release
- Too many changes since 23.04.3, only listing bugfixes:
  * Fix kdeconnect_open desktop file type (kde#424782)
  * When receiving files, delay de-duplicating filenames (kde#470078)
  * Use explicit constructor for QSslCertificate with value initialized argument (kde#469428)
  * Fix inactive "Send Arrow" in smsapp after first message sent (kde#455149)
  * Improve bigscreen plugin description (kde#468143)
  * Run command settings: add import and export buttons (kde#409388)
  * Use `org.freedesktop.DBus.Monitoring` to monitor notifications (kde#447385)
- Drop patch, merged upstream:
  * Use-org-freedesktop-DBus-Monitoring-to-monitor-notifications.patch
* Mon Jul 24 2023 Fusion Future <qydwhotmail@gmail.com>
- Require kirigami-addons: used in app/qml/Settings.qml
* Tue Jul  4 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.04.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.04.3/
- Changes since 23.04.2:
  * Fix kdeconnect_open desktop file type (kde#424782)
  * Use explicit constructor for QSslCertificate with value initialized argument (kde#469428)
* Tue Jun  6 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.04.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.04.2/
- No code change since 23.04.1
* Sun May 21 2023 Fusion Future <qydwhotmail@gmail.com>
- Add patch to avoid incorrect notification IDs from the notification
  plugin (kde#447385):
  * Use-org-freedesktop-DBus-Monitoring-to-monitor-notifications.patch
* Tue May  9 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.04.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.04.1/
- No code change since 23.04.0
* Sat Apr 15 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.04.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/23.04.0/
* Fri Mar 31 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.03.90
  * New feature release
* Fri Mar 17 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.03.80
  * New feature release
* Fri Mar 17 2023 Fabian Vogt <fabian@ritter-vogt.de>
- Fix some potential scriptlet bugs and style issues
* Wed Mar  8 2023 Robert Frohl <rfrohl@suse.com>
- Automatically handle firewalld setup during initial install or final removal
  of kdeconnect-kde for openSUSE distros. (boo#1175627)
- Drop kdeconnect-kde-firewalld.xml, service definition now shipped with
  firewalld package.
  * the 'kdeconnect-kde' firewalld service is migrated over to 'kdeconnect'
* Tue Feb 28 2023 Christophe Marin <christophe@krop.fr>
- Update to 22.12.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.12.3/
* Tue Jan 31 2023 Christophe Marin <christophe@krop.fr>
- Update to 22.12.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.12.2/
* Tue Jan  3 2023 Christophe Marin <christophe@krop.fr>
- Update to 22.12.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.12.1/
* Fri Dec  2 2022 Christophe Marin <christophe@krop.fr>
- Update to 22.12.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/22.12.0/
* Sat Nov 26 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.11.90
  * New feature release
* Sat Nov 12 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.11.80
  * New feature release
* Tue Nov  1 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.08.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.08.3/
* Tue Oct 11 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.08.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.08.2/
* Tue Sep  6 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.08.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.08.1/
* Sun Aug 14 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.08.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/22.08.0/
* Fri Aug  5 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.07.90
  * New feature release
* Sat Jul 16 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.07.80
  * New feature release
* Tue Jul  5 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.04.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.04.3/
* Wed Jun  8 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.04.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.04.2/
* Tue May 10 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.04.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.04.1/
* Mon Apr 18 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.04.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/22.04.0/
* Fri Apr  8 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.03.90
  * New feature release
* Wed Mar 23 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.03.80
  * New feature release
- Too many changes since 21.12.3, only listing bugfixes:
  * [Connectivity Report] Fixed crash if signalStrengths is
    empty. (kde#449276)
  * [SMS App] Prevent crash if a conversation doesn't have
    any messages (kde#449719)
  * Change tray icon so it is the right color on MacOS (kde#430226)
  * Raise configuration window (MacOS bug) (kde#416050)
  * plasmoid: Don't show redundant configure button in
    placeholder message (kde#448457)
  * Always show notification when receiving files (kde#417823)
* Mon Mar  7 2022 Christophe Giboudeaux <christophe@krop.fr>
- Replace %%_libdir/libexec with %%_libexecdir (boo#1174075)
* Tue Mar  1 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.12.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.12.3/
- No code change since 21.12.2
* Tue Feb  1 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.12.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.12.2/
- No code change since 21.12.1
* Tue Jan  4 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.12.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.12.1/
- Changes since 21.12.0:
  * Mark settings and SMS app as single window
  * [settings] Rename desktop file to match desktop entry defined
    by KAboutData
  * Disable Battery plugin on Windows
* Fri Dec  3 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.12.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/21.12.0/
- No code change since 21.11.90
* Sat Nov 27 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.11.90
  * New feature release
- Changes since 21.11.80:
  * Fix unicode-decoding mistake in isInGsmAlphabet method
  * Always show notification when receiving files (kde#417823)
- Drop kdeconnect-add-back-ssh-dss.patch
* Sat Nov 13 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.11.80
  * New feature release
- Too many changes to list here.
- Drop kdeconnect-openssh-8.8.patch
* Tue Nov  2 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.08.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.08.3/
- Changes since 21.08.2:
  * [handler] Enable highdpi pixmaps
* Sun Oct 31 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Make sshfs depencency versioned for kdeconnect-openssh-8.8.patch
- Add patch to add back option removed by kdeconnect-openssh-8.8.patch:
  * kdeconnect-add-back-ssh-dss.patch
* Sun Oct 31 2021 munix9@googlemail.com
- Add kdeconnect-openssh-8.8.patch (boo#1191886),
  (kde#351725) and (kde#443155)
  See also https://bugs.archlinux.org/task/72350
* Tue Oct  5 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.08.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.08.2/
- Changes since 21.08.1:
  * [sendreplydialog] Move focus on tab
  * [sendreplydialog] Submit on enter, enter newline on shift+enter
  * Install status icons again
* Wed Sep  1 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.08.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.08.1
- No code change since 21.08.0
* Fri Aug  6 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.08.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/21.08.0
- No code change since 21.07.90
* Fri Jul 30 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.07.90
  * New feature release
- Changes since 21.07.80:
  * Set breeze as fallback icon theme for all executables
  * Add missing KF5WindowSystem dependency
* Sat Jul 17 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.07.80
  * New feature release
- Too many changes since 21.04.3, only listing bugfixes:
  * Push a new layer when entering About Page in the SMS App (kde#423932)
  * Link to proper website in appstream (kde#437205)
  * mousepad: Default to scrolling up when fingers move up
    on the android version (kde#410156)
  * Add support for clipboard integration (kde#359747)
* Wed Jul  7 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.04.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.04.3
- Changes since 21.04.2:
  * fix Windows build by triggering KIconLoader when indicator starts
  * Disable kpeople qml module finding
* Thu Jun 17 2021 Christophe Giboudeaux <christophe@krop.fr>
- Make sure the required plugins are installed (boo#1187440)
* Tue Jun  8 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.04.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.04.2
- Changes since 21.04.1:
  * [SMS App] Fix message sending area from always having a white background (kde#434791)
* Wed May 12 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.04.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/21.04.1
- No code change since 21.04.0
* Fri Apr 16 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.04.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/21.04
- Changes since 21.03.90:
  * Remove unused Plasma imports in RemoteKeyboard.qml
- Stop owning directories provided by the filesystem package (boo#1184786)
* Fri Apr  9 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.03.90
  * New feature release
- Changes since 21.03.80:
  * Don’t extract QML strings as Java printf strings
  * [interfaces] Make KConfig linkage public
* Sun Mar 21 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.03.80
  * New feature release
- Too many changes since 20.12.3, only listing bugfixes:
  * [plasmoid] Use PlaceholderMessage from PlasmaExtras instead of Kirigami (kde#434197)
  * Fix notifications in the KDE Connect plasmoid (kde#432337)
  * kdeconnect_daemon: conditionally configure the daemon service
    to better support the Windows port (kde#412665)
* Thu Mar  4 2021 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.12.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/20.12.3
- Changes since 20.12.2:
  * Don't escape notification title text
- Dropped patch, now upstream:
  * 0001-Don-t-escape-notification-title-text.patch
* Wed Feb  3 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 20.12.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2021-02-apps-update
- Changes since 20.12.1:
  * Fix notifications in the KDE Connect plasmoid (kde#432337)
  * UseHighDpiPixmaps in kdeconnectd and kdeconnect-indicator
  * Remove OnlyShowIn from daemon desktop file
- Add upstream patch:
  * 0001-Don-t-escape-notification-title-text.patch
* Tue Jan  5 2021 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.12.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2021-01-apps-update
- Changes since 20.12.0:
  * plugins/battery: add battery charge info to the update signal
* Mon Dec 21 2020 Christophe Giboudeaux <christophe@krop.fr>
- Add missing runtime requirements (boo#1180272)
* Sat Dec  5 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.12.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-12-apps-update
- Changes since 20.11.90:
  * [SMS App] Disable sending attachments until we have Android support
  * Fix build with bluetooth enabled
* Fri Nov 27 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 20.11.90
  * New feature release
- Changes since 20.11.80:
  * Add a verification key that's displayed when pairing
* Sat Nov 14 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 20.11.80
  * New feature release
- Too many changes to list here.
* Thu Nov  5 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.08.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-11-apps-update
- Changes since 20.08.2:
  * Set window icons for GUI executables
  * Work around SMS not being sent from cli
  * Update kdeconnect-cli send-sms interface. (kde#425731)
  * Fix missing kcm dependency for runcommand module
* Fri Oct  9 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.08.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-10-apps-update
- Too many changes to list here.
- Dropped patches, now upstream:
  * 0001-Do-not-leak-the-local-user-in-the-device-name.patch
  * 0002-Fix-use-after-free-in-LanLinkProvider-connectError.patch
  * 0003-Limit-identity-packets-to-8KiB.patch
  * 0004-Do-not-let-lanlink-connections-stay-open-for-long-wi.patch
  * 0005-Don-t-brute-force-reading-the-socket.patch
  * 0006-Limit-number-of-connected-sockets-from-unpaired-devi.patch
  * 0007-Do-not-remember-more-than-a-few-identity-packets-at-.patch
  * 0008-Limit-the-ports-we-try-to-connect-to-to-the-port-ran.patch
  * 0009-Do-not-replace-connections-for-a-given-deviceId-if-t.patch
* Fri Oct  2 2020 Luca Beltrame <lbeltrame@kde.org>
- Add upstream patches to fix security issues in kdeconnect
  (CVE-2020-26164, boo#1176268):
  * 0001-Do-not-leak-the-local-user-in-the-device-name.patch
  * 0002-Fix-use-after-free-in-LanLinkProvider-connectError.patch
  * 0003-Limit-identity-packets-to-8KiB.patch
  * 0004-Do-not-let-lanlink-connections-stay-open-for-long-wi.patch
  * 0005-Don-t-brute-force-reading-the-socket.patch
  * 0006-Limit-number-of-connected-sockets-from-unpaired-devi.patch
  * 0007-Do-not-remember-more-than-a-few-identity-packets-at-.patch
  * 0008-Limit-the-ports-we-try-to-connect-to-to-the-port-ran.patch
  * 0009-Do-not-replace-connections-for-a-given-deviceId-if-t.patch
* Tue Sep  1 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.08.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-09-apps-update
- Changes since 20.08.0:
  * [kio] Mark Class as local (kde#413477)
  * Reload remote commands model when commands change
  * Define content margins for settings app
  * appdata: use canonical help URL
* Wed Aug 19 2020 Callum Farmer <callumjfarmer13@gmail.com>
- Fixes for %%_libexecdir changing to /usr/libexec (bsc#1174075)
* Sun Aug  9 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 20.08.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-08-apps-update
- No code change since 20.07.90
* Sun Aug  2 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 20.07.90
  * New feature release
- Changes since 20.07.80:
  * Fix file dialog usage in app and plasmoid (kde#423975)
* Sun Jul 19 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 20.07.80
  * New feature release
- Too many changes since 20.04.3, only listing bugfixes:
  * [SMS App] Select Message Text (kde#418630)
  * Finally, we have support for sending out Battery information. (kde#357193)
- Drop 0001-Use-ecm_qt_declare_logging_category-to-declare-the-l.patch.
  Merged upstream
* Thu Jul  9 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.04.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-07-apps-update
- Changes since 20.04.2:
  * Add explanatory comment
  * Prefer qdbus-qt5 if found
- Dropped patches, adopted upstream:
  * 0001-Use-qdbus-qt5.patch
* Thu Jul  2 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Add patch to fix suggested commands in the runcommand config:
  * 0001-Use-qdbus-qt5.patch
* Tue Jun  9 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 20.04.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-06-apps-update
- Changes since 20.04.1:
  * Fix findthisdevice sound URL
  * Remove windows CI in stable too
* Wed May 27 2020 Antonio Larrosa <alarrosa@suse.com>
- Add patch submitted upstream to use
  ecm_qt_declare_logging_category so users can easily modify the
  debugging configuration and use a default logging level of
  Warning instead of sending all debug messages to the log:
  * 0001-Use-ecm_qt_declare_logging_category-to-declare-the-l.patch
* Fri May 15 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.04.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-05-apps-update
- Changes since 20.04.0:
  * Unmute audio when volume changes (kde#408705)
* Thu Apr 23 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.04.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-04-apps-update
- No code change since 20.03.90
* Sun Apr  5 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.03.90
  * New feature release
- Changes since 20.03.80:
  * Exception doesn't have strerr
  * Check for null notification
  * [fileitemactionplugin] Use async DBus call (kde#419133)
  * Improve call notification handling
  * Read payload size as qint64
  * Use kdeconnect-settings for command configuration
* Sun Mar 22 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.03.80
  * kdeconnect-kde is now part of the KDE applications release
    service
* Sat Jan 25 2020 wbauer@tmo.at
- Update to 1.4
  * New "KDE Connect" desktop app to control the phone from the PC
  * SMS app that can read and write SMS texts
  * control PC system's global volume from a phone
  * flip forward and back through presentation slides
  * compatibility with Thunar (Xfce's file manager) and Elementary
    applications such as Pantheon Files.
- Run spec-cleaner
* Tue Jul 30 2019 wbauer@tmo.at
- Update to 1.3.5
  * Add detectPlatform to always use wayland in a wayland session
  * i18n: fix extraction of nautilus extension
  * Don't update new notifications
  * Install desktop file for kdeconnectd
  * [sftp] Fix error message wording
  * Change plugin name
  * [sftp] Give better error messages for common errors
  * [sftp] Improve error reporting
  * Use KAboutData to set information about the daemon
  * Disable session management
  * Print socket error when connection fails
  * [kio] Mount device during stat if necessary
  * [backends/lan] Don't fail silently when a UDP packet could not
    be unserialized
  * Fix crash in daemon
  * Fix crash in notifications plugin (kde#400010)
  * Don't show multiple windows when replying to a notification
- Drop Leap 42.3 specific patches, it's no longer supported:
  * 0001-Fix-build-on-Leap-42.3.patch
  * 0001-Revert-Retry-the-network-packet-if-it-failed-to-unse.patch
- Don't install SuSEfirewall2 file on Tumbleweed anymore, Sf2 has
  been dropped
* Mon Apr  1 2019 Jan Engelhardt <jengelh@inai.de>
- Use noun phrase in descriptions.
* Mon Mar 25 2019 wbauer@tmo.at
- Update to 1.3.4
  * Always play when call ended (kde#400787)
  * [cli] Show all reachable devices (kde#402088)
  * [sftp] Get device ID from URL
  * Retry the network packet if it failed to unserialize
  * Fix sending keys via CLI
  * [kio] Fix file browsing with non-KIO file managers
- Run spec-cleaner
- Refresh 0001-Fix-build-on-Leap-42.3.patch
- Add 0001-Revert-Retry-the-network-packet-if-it-failed-to-unse.patch
  to make it build on Leap 42.3
- Drop Provides/Obsoletes for kdeconnect-kde-devel, that package
  doesn't exist anymore since 2015 and nothing should need it
* Wed Nov 14 2018 wbauer@tmo.at
- Add 0001-Fix-build-on-Leap-42.3.patch to make it build on Leap
  42.3
* Wed Nov  7 2018 wbauer@tmo.at
- Update to 1.3.3
  * Instantiate QApplication object to fix crash on KDE Neon
    (kde#400178)
  * Fix build failure on musl based systems (kde#395161)
* Thu Oct 18 2018 wbauer@tmo.at
- Update to 1.3.2
  * Also allow modern algorithms, for compat with future apps
  * Remove characters from UUID that aren't legal in URLs
  * Add new notifications at the top of the list
  * Change the 'Dismiss all notifications' icon
  * Fix DBus signals in Mprisremote
* Fri Jun  1 2018 wbauer@tmo.at
- Update to 1.3.1
  * Fix a bug that would hang Nautilus when copying a file if
    paired devices were available
  * Fix remote filesystem reconnection issue
  * Add a missing dependency check in cmake
  * Add missing notification category to the plasmoid
- Mark license file with %%license instead of %%doc
* Mon Apr  9 2018 kamikazow@opensuse.org
- Update to 1.3.0
  * Fixed frequent crash when receiving notifications
  * Fixed MPRIS player entries never being deleted
  * Added a Gnome Files (Nautilus) extension to send files from the
    context menu
  * Added handling of "tel:" links with KDE Connect
  * Support sending album art in MPRIS plugin
  * Allow sharing more than one file from the CI (eg: --share *.mp3)
- Remove patches, now upstream:
  * 0001-Fix-null-dereference.patch
- Modified wording in Description to match that KDE Connect
  runs under any Linux desktop (see upstream README.md file)
* Tue Feb 20 2018 alarrosa@suse.com
- Add 0001-Fix-null-dereference.patch to fix a null dereference.
- Add signature file kdeconnect-kde-v1.2.1.tar.xz.sig
* Thu Jan 18 2018 wbauer@tmo.at
- Update to 1.2.1
  * Require the latest version of KF5
  * Was getting a double-delete, now it won't crash
  * Get rid of ProcessRunner
  * Add album art to mpris network packets
  * Add title, artist and album to MPRIS network packets
  * Fix information leak via /tmp (kde#383144)
  * Add support for new Android 2.3 (API 9+) cipher
  * Fix kdeconnect-cli device list
  * Fix "error activiting kdeconnectd" for kdeconnect-cli
  * Delay kdeconnectd autostart phase
  * Fix Notifications in Plasmoid
  * Make sure there's not a path within the filename
  * share plugin: fix path display
  * Use pactl instead of KMix in PauseMusic Plugin
- needs KDE Frameworks 5.42 now
* Sun Oct  1 2017 wbauer@tmo.at
- Update to 1.2.0
- Update build requirements, it needs Qt 5.7 and KF 5.38 now
- Remove patches, now upstream:
  * 0001-Treat-device-names-as-plaintext-not-rich-text.patch
* Wed Jul 12 2017 fabian@ritter-vogt.de
- Add patch to fix unauthenticated HTML injection (kde#382243):
  * 0001-Treat-device-names-as-plaintext-not-rich-text.patch
* Fri Dec 23 2016 ecsos@opensuse.org
- Update to 1.0.3
* Sat Nov 12 2016 hrvoje.senjan@gmail.com
- Update to 1.0.2
* Wed Sep 21 2016 wbauer@tmo.at
- Update to 1.0.1
  * fixes some issues found in 1.0
- Drop upstreamed fix-build-with-older-qt.patch
* Wed Sep  7 2016 wbauer@tmo.at
- Add fix-build-with-older-qt.patch from upstream to make it
  compile with Qt < 5.6, and lower the Qt requirement to 5.2 again
  (as demanded by CMakeLists.txt)
* Fri Aug 26 2016 herbert@graeber-clan.de
- Add firewalld service file
* Fri Aug 26 2016 fabian@ritter-vogt.de
- Build docs again
- Require at least Qt 5.6
* Fri Aug 26 2016 lbeltrame@kde.org
- New upstream version 1.0
  * Trigger custom commands from phone
  * Reply to SMS messages from the desktop
  * Receive desktop notifications on phone
  * TLS encryption
* Mon Feb  1 2016 hrvoje.senjan@gmail.com
- Update to 0.9g
  * No changelog provided
- Drop upstreamed 0001-This-syntax-also-works-on-older-OpenSSH-versions.patch
* Thu Jan 14 2016 alarrosa@suse.com
- Add 0001-This-syntax-also-works-on-older-OpenSSH-versions.patch from
  upstream to be compatible with older openssh versions (bnc#961554)
* Mon Nov 30 2015 toddrme2178@gmail.com
- Update to 0.9f
  * Adds translations
- Update to 0.9
  * KF5 version
* Fri Feb 20 2015 hrvoje.senjan@gmail.com
- Update to 0.8
  * No changelog provided
* Mon Jan 12 2015 tittiatcoke@gmail.com
- Add Requires:  sshfs  to make it work.
* Thu Oct 16 2014 hrvoje.senjan@gmail.com
- Update to 0.7.3:
  * No changelog provided
* Fri Sep 12 2014 hrvoje.senjan@gmail.com
- Update to 0.7.2:
  * No changelog provided
* Tue Jul  1 2014 fisiu@opensuse.org
- Update to 0.7.1:
  * Touchpad allows to scroll with 2 fingers, middle and right click.
  * Minor fixes.
* Sat Jun 28 2014 fisiu@opensuse.org
- Update to 0.7:
  * Use phone as cursor controller.
  * Allow android phone to receive files from PC.
  * Many bug fixes.
  * Translation available in 25 languages.
* Fri May 16 2014 hrvoje.senjan@gmail.com
- Update to 0.5.2.1
  * New upstream release, no changelog provided
* Sun Mar  9 2014 hrvoje.senjan@gmail.com
- Update to 0.5.1
  * New upstream release, no changelog provided
* Sat Feb 22 2014 fisiu@opensuse.org
- Update to 0.5.
- Build language package.
* Sat Dec 21 2013 fisiu@opensuse.org
- Add kdeconnect-kde.SuSEfirewall: config file for SuSEfirewall2.
* Fri Dec 20 2013 fisiu@opensuse.org
- Update to 0.4.2:
  * Plasmoid now displays the devices' battery.
  * Added standalone binary to run kdeconnect without kded.
  * Added a config dialog to pausemusic plugin.
  * Share plugin changed name.
  * The battery percentage for low battery level is now signaled by the device.
* Mon Nov 11 2013 hrvoje.senjan@gmail.com
- Update to version 0.4.1
  * New feature release, no changelog provided
* Tue Nov  5 2013 hrvoje.senjan@gmail.com
- Update to version 0.4
  * New feature release, no changelog provided
- Remove lang tar, translations removed also from tar
- BuildRequire libqjson-devel >= 0.8, as it doesn't build with older
  QJson
* Thu Oct  3 2013 hrvoje.senjan@gmail.com
- Update to version 0.3
  * New feature release
- Added lang tarball
* Mon Sep  9 2013 toddrme2178@gmail.com
- Initial version (0.1)
